<?php

/**
 * Upgrade notice for customers
 *
 * @link
 * @since 1.3.8
 *
 * @package  Cookie_Law_Info
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
class Woo_Inpost_Upgrade_Notice {

	protected $plugin_id       = 'woo-inpost';
	protected $modal_class     = 'woo_inpost_popup';
	protected $plugin_file     = 'woo-inpost/woo-inpost.php'; // plugin main file.

	public function __construct() {

		add_action( 'admin_footer', array( $this, 'deactivate_scripts' ) );
		add_filter( 'plugin_action_links_' . $this->plugin_file, array( $this, 'plugin_action_links' ) );
	}

	public function plugin_action_links( $links ) {

		if ( array_key_exists( 'deactivate', $links ) ) {
			$links['deactivate'] = str_replace( '<a', '<a class="' . $this->plugin_id . '-deactivate-link"', $links['deactivate'] );
		}
		return $links;
	}


	public function deactivate_scripts() {
		global $pagenow;
		if ( 'plugins.php' != $pagenow ) {
			return;
		}
		?>
		<div class="<?php echo esc_attr( $this->modal_class ); ?>-modal" id="<?php echo esc_attr( $this->modal_class ); ?>-modal">
			<div class="<?php echo esc_attr( $this->modal_class ); ?>-modal-wrap">
				<div class="<?php echo esc_attr( $this->modal_class ); ?>-modal-header">
					<h3><?php echo esc_html__( 'Dziękujemy za korzystanie z naszej wtyczki "InPost dla WooCommerce"!', 'woo-inpost' ); ?></h3>
				</div>
				<div class="<?php echo esc_attr( $this->modal_class ); ?>-modal-body">

					<p style="font-size:16px">
                        Chcielibyśmy poinformować, że zaprzestaliśmy wsparcia dla tej wtyczki.
                    </p>
                    <p style="font-size:16px">
                        Udostępniliśmy nową wersję wtyczki InPost, która jest już dostępna w repozytorium Wordpress.
                    </p>
                    <p style="font-size:16px">
                        <b style="color:#FF0000">Uwaga:</b> wyłącz starą wtyczkę przed aktywacją nowej, aby uniknąć konfliktów.
                    </p>

                    <a class="button-primary woo-inpost-green" href="https://wordpress.org/plugins/inpost-for-woocommerce/" target="_blank">
                        <span class="dashicons dashicons-external" style="margin-top:3px;"></span>
                        <?php echo esc_html__( 'Przejdź do strony z nową wtyczką', 'woo-inpost' ); ?>
                    </a>
				</div>

				<div class="<?php echo esc_attr( $this->modal_class ); ?>-modal-footer">

					<button class="button-primary <?php echo esc_attr( $this->modal_class ); ?>-model-submit">
                        <?php echo esc_html__( 'Zrozumiano. Dezaktywuj', 'woo-inpost' ); ?>
                    </button>
					<button class="button-secondary <?php echo esc_attr( $this->modal_class ); ?>-model-cancel">
                        <?php echo esc_html__( 'Zamknąć', 'woo-inpost' ); ?>
                    </button>

				</div>
			</div>
		</div>
		<style type="text/css">
			.woo_inpost_popup-modal {
				position: fixed;
				z-index: 99999;
				top: 0;
				right: 0;
				bottom: 0;
				left: 0;
				background: rgba(0, 0, 0, 0.5);
				display: none;
			}

			.woo_inpost_popup-modal.modal-active {
				display: block;
			}
            .woo_inpost_popup-modal-footer {
                height: 30px;
            }

			.woo_inpost_popup-modal-wrap {
				width: 50%;
				position: relative;
				margin: 10% auto;
				background: #fff;
			}

			.woo_inpost_popup-modal-header {
				border-bottom: 1px solid #eee;
				padding: 8px 20px;
			}

			.woo_inpost_popup-modal-header h3 {
				line-height: 150%;
				margin: 0;
			}

			.woo_inpost_popup-modal-body {
				padding: 5px 20px 20px 20px;
			}

			.woo_inpost_popup-modal-body .input-text,
			.woo_inpost_popup-modal-body textarea {
				width: 75%;
			}

			.woo_inpost_popup-modal-body .reason-input {
				margin-top: 5px;
				margin-left: 20px;
			}

			.woo_inpost_popup-modal-footer {
				border-top: 1px solid #eee;
				padding: 12px 20px;
				text-align: left;
			}

			.woo_inpost_popup-sub-reasons {
				display: none;
				padding-left: 20px;
				padding-top: 10px;
				padding-bottom: 4px;
			}

			.wt-uninstall-feedback-privacy-policy {
				text-align: left;
				font-size: 12px;
				color: #aaa;
				line-height: 14px;
				margin-top: 20px;
				font-style: italic;
			}

			.wt-uninstall-feedback-privacy-policy a {
				font-size: 11px;
				color: #4b9cc3;
				text-decoration-color: #99c3d7;
			}
            .button-primary.woo-inpost-green {
                background: #2a9926;
                border-color: #2a9926;
                padding: 5px 18px;
                border-radius: 7px;
            }
            .button-primary.woo-inpost-green:hover {
                background: #5fdf5b;
                border-color: #5fdf5b;
            }
		</style>
		<script type="text/javascript">
			(function($) {
				$(function() {
					var plugin_id = '<?php echo esc_js( $this->plugin_id ); ?>';
					var modal_class = '<?php echo esc_js( $this->modal_class ); ?>';
					var modal = $('#' + modal_class + '-modal');
					var deactivateLink = '';
					$('a.' + plugin_id + '-deactivate-link').click(function(e) {
						e.preventDefault();
                        $('.woo_inpost_popup-model-submit').show('display', 'block');
						$('.woo_inpost_popup-model-cancel').css('float', 'right');
						modal.addClass('modal-active');
						deactivateLink = $(this).attr('href');

					});
					modal.on('click', 'button.' + modal_class + '-model-cancel', function(e) {
						e.preventDefault();
						modal.removeClass('modal-active');
					});

					modal.on('click', 'button.' + modal_class + '-model-submit', function(e) {
						e.preventDefault();
						var button = $(this);
						if (button.hasClass('disabled')) {
							return;
						}
                        window.location.href = deactivateLink;
					});
				});
			}(jQuery));
		</script>

        <?php if( get_option( 'woo_inpost_show_popup_once', false ) ) {
            delete_option( 'woo_inpost_show_popup_once' );
            ?>

            <script type="text/javascript">
                (function($) {
                    var modal_class = 'woo_inpost_popup';
                    var modal = $('#' + modal_class + '-modal');
                    $('.woo_inpost_popup-model-submit').css('display', 'none');
                    modal.addClass('modal-active');

                }(jQuery));
            </script>

            <?php
        }
	}


}
new Woo_Inpost_Upgrade_Notice();
